#!/usr/bin/env python

#-----------------------------------------------------------------------
# httpclient1.py
# Author: Bob Dondero
#-----------------------------------------------------------------------

import sys
import socket

def main():

    if len(sys.argv) != 4:
        print('Usage: python %s host port file' % sys.argv[0])
        sys.exit(1)

    try:
        host = sys.argv[1]
        port = int(sys.argv[2])
        file_name = sys.argv[3]

        with socket.socket() as sock:
            sock.connect((host, port))

            out_flo = sock.makefile(mode='w', encoding='iso-8859-1')
            out_flo.write('GET ' + file_name + ' HTTP/1.1\r\n')
            out_flo.write('Host: ' + host + '\r\n')
            out_flo.write('\r\n')
            out_flo.flush()

            # Read the headers from the socket, and write them
            # to stdout.
            in_flo = sock.makefile(mode='r', encoding='iso-8859-1')
            for line in in_flo:
                print(line, end='')
                if line == '\n':
                    break

            # Read the file's content from the socket.
            # A smarter program would examine the headers to
            # determine how to interpret the file content.  Here,
            # assume that the file contains iso-8859-1 characters.
            for line in in_flo:
                print(line, end='')

    except Exception as ex:
        print(ex, file=sys.stderr)
        sys.exit(1)

if __name__ == '__main__':
    main()
